<?php
/**
 * FuzeWorks CLIComponent
 *
 * The FuzeWorks PHP FrameWork
 *
 * Copyright (C) 2013-2021 i15
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 *
 * @author    i15
 * @copyright Copyright (c) 2013 - 2021, i15. (https://i15.nl)
 * @license   https://opensource.org/licenses/MIT MIT License
 *
 * @since Version 1.2.0
 *
 * @version Version 1.2.0
 */

namespace FuzeWorks\CLI;


class Output
{

    protected array $colors = [
        '&0' => '0;30',
        '&1' => '0;34',
        '&2' => '0;32',
        '&3' => '0;36',
        '&4' => '0;31',
        '&5' => '0;35',
        '&6' => '0;33',
        '&7' => '0;37',
        '&8' => '1;30',
        '&9' => '1;34',
        '&a' => '1;32',
        '&b' => '1;36',
        '&c' => '1;31',
        '&d' => '1;35',
        '&e' => '1;33',
        '&f' => '1;37',
        '&r' => '0'
    ];

    public function charsOut(string $output): void
    {
        echo $this->parseOutput($output);
    }

    public function lineOut(string $output): void
    {
        echo $this->parseOutput($output) . "\n";
    }

    public function warningOut(string $output): void
    {
        $this->lineOut('&4[&eWARNING&4] &e' . $output . '&r');
    }

    public function errorOut(string $output): void
    {
        $this->lineOut('&4[&eERROR&4] &c' . $output . '&r');
    }

    protected function parseOutput(string $output): string
    {
        // First parse for colors
        foreach ($this->colors as $colorKey => $colorVal) {
            $output = str_replace($colorKey, "\033[" . $colorVal . 'm', $output);
        }

        return $output;
    }

}